# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['flask_googlemaps']

package_data = \
{'': ['*'], 'flask_googlemaps': ['templates/googlemaps/*']}

install_requires = \
['flask>=0.10']

setup_kwargs = {
    'name': 'flask-googlemaps',
    'version': '0.3.0',
    'description': 'Easy way to add GoogleMaps to Flask Applications',
    'long_description': '# Flask Google Maps\n\n[![Flask Estension](https://img.shields.io/badge/flask-extension-green.svg?style=flat)](https://flaskextensions.com)\n<a target="_blank" href="https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=rochacbruno%40gmail%2ecom&amp;lc=BR&amp;item_name=FlaskGoogleMaps&amp;no_note=0&amp;currency_code=USD&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest"><img alt=\'Donate with Paypal\' src=\'http://www.paypalobjects.com/en_US/i/btn/btn_donate_SM.gif\' /></a>\n\nEasy to use Google Maps in your Flask application\n\n## requires\n\n- Jinja\n- Flask\n- A google api key [get here](https://developers.google.com/maps/documentation/javascript/get-api-key)\n\n\n## Installation\n\n```pip install flask-googlemaps```\n\nor\n\n```bash\n\ngit clone https://github.com/rochacbruno/Flask-GoogleMaps\ncd Flask-GoogleMaps\npython setup.py install\n\n```\n\n## How it works\n\nFlask-GoogleMaps includes some global functions and template filters in your Jinja environment, also it allows you to use the Map in views if needed.\n\n\n### registering\n\nin your app\n\n```python\n\nfrom flask import Flask\nfrom flask_googlemaps import GoogleMaps\n\napp = Flask(__name__)\n\n# you can set key as config\napp.config[\'GOOGLEMAPS_KEY\'] = "8JZ7i18MjFuM35dJHq70n3Hx4"\n\n# Initialize the extension\nGoogleMaps(app)\n\n# you can also pass the key here if you prefer\nGoogleMaps(app, key="8JZ7i18MjFuM35dJHq70n3Hx4")\n\n```\n\nIn template\n\n```html\n\n{{googlemap("my_awesome_map", lat=0.23234234, lng=-0.234234234, markers=[(0.12, -0.45345), ...])}}\n\n```\n\nThat\'s it! now you have some template filters and functions to use, more details in examples and screenshot below.\n\n\n\n### Usage\n\n- You can create the map in the view and then send to the template context\n- you can use the template functions and filters directly\n\n\n#### 1. View\n\n```python\n\nfrom flask import Flask, render_template\nfrom flask_googlemaps import GoogleMaps\nfrom flask_googlemaps import Map\n\napp = Flask(__name__, template_folder=".")\nGoogleMaps(app)\n\n@app.route("/")\ndef mapview():\n    # creating a map in the view\n    mymap = Map(\n        identifier="view-side",\n        lat=37.4419,\n        lng=-122.1419,\n        markers=[(37.4419, -122.1419)]\n    )\n    sndmap = Map(\n        identifier="sndmap",\n        lat=37.4419,\n        lng=-122.1419,\n        markers=[\n          {\n             \'icon\': \'http://maps.google.com/mapfiles/ms/icons/green-dot.png\',\n             \'lat\': 37.4419,\n             \'lng\': -122.1419,\n             \'infobox\': "<b>Hello World</b>"\n          },\n          {\n             \'icon\': \'http://maps.google.com/mapfiles/ms/icons/blue-dot.png\',\n             \'lat\': 37.4300,\n             \'lng\': -122.1400,\n             \'infobox\': "<b>Hello World from other place</b>"\n          }\n        ]\n    )\n    return render_template(\'example.html\', mymap=mymap, sndmap=sndmap)\n\nif __name__ == "__main__":\n    app.run(debug=True)\n\n```\n\n##### `Map()` Parameters\n\n- **lat**: The latitude coordinate for centering the map.\n- **lng**: The longitutde coordinate for centering the map.\n- **zoom**: The zoom level. Defaults to `13`.\n- **maptype**: The map type - `ROADMAP`, `SATELLITE`, `HYBRID`, `TERRAIN`. Defaults to `ROADMAP`.\n- **markers**: Markers array of tuples having (**lat**, **lng**, infobox, icon). Defaults to `None`.\n- or **markers**: a list of dicts containing **icon, lat, lng, infobox**.\n- or **markers**: Markers dictionary with icon urls as keys and markers array as values.\n- **varname**: The instance variable name.\n- **style**: A string containing CSS styles. Defaults to `"height:300px;width:300px;margin:0;"`.\n- **identifier**: The CSS ID selector name.\n- **cls**: The CSS Class selector name. Defaults to `"map"`.\n- **language**: The map language. Defaults to `"en"`.\n- **region**: The map region. Defaults to `"US"`.\n\nAlso controls True or False:\n\n- zoom_control\n- maptype_control\n- scale_control\n- scale_control\n- streetview_control\n- rotate_control\n- fullscreen_control\n- scroll_wheel\n- collapsible (map collapses by click on **varname**_collapse button)\n- center_on_user_location (using HTML5 Geolocation)\n\n#### 2. Template\n\n```html\n\n<!DOCTYPE html>\n    <html>\n    <head>\n            {{"decoupled-map"|googlemap_js(37.4419, -122.1419, markers=[(37.4419, -122.1419)])}}\n            {{mymap.js}}\n            {{sndmap.js}}\n    </head>\n    <body>\n        <h1>Flask Google Maps Example</h1>\n\n        <h2> Template function centered, no marker </h2>\n        {{googlemap("simple-map", 37.4419, -122.1419)}}\n\n        <h2> Template filter decoupled with single marker </h2>\n        {{"decoupled-map"|googlemap_html(37.4419, -122.1419)}}\n\n        <h2> Template function with multiple markers </h2>\n        {% with map=googlemap_obj("another-map", 37.4419, -122.1419, markers=[(37.4419, -122.1419), (37.4300, -122.1400)]) %}\n            {{map.html}}\n            {{map.js}}\n        {% endwith %}\n\n        <h2> First map generated in view</h2>\n        {{mymap.html}}\n\n        <h2> Second map generated in view</h2>\n        <h3> Example for different icons in multiple markers with infoboxes</h3>\n        {{sndmap.html}}\n\n    </body>\n</html>\n\n```\n\n### Infobox\n\nHere\'s an example snippet of code:\n```python\n\n    Map(\n        identifier="catsmap",\n        lat=37.4419,\n        lng=-122.1419,\n        markers=[\n            {\n                \'icon\': \'http://maps.google.com/mapfiles/ms/icons/green-dot.png\',\n                \'lat\':  37.4419,\n                \'lng\':  -122.1419,\n                \'infobox\': "<img src=\'cat1.jpg\' />"\n            },\n            {\n                \'icon\': \'http://maps.google.com/mapfiles/ms/icons/blue-dot.png\',\n                \'lat\': 37.4300,\n                \'lng\': -122.1400,\n                \'infobox\': "<img src=\'cat2.jpg\' />"\n            },\n            {\n                \'icon\': \'http://maps.google.com/mapfiles/ms/icons/yellow-dot.png\',\n                \'lat\': 37.4500,\n                \'lng\': -122.1350,\n                \'infobox\': "<img src=\'cat3.jpg\' />"\n            }\n        ]\n    )\n\n```\n\nWhich results in something like the following map:\n<img width="1439" alt="screen shot 2015-07-29 at 2 41 52 pm" src="https://cloud.githubusercontent.com/assets/8108300/8969650/13b0de7a-3602-11e5-9ed0-9f328ac9253f.png">\n\n\n### Fit all markers within bounds\n\nAllow users to easily fit all markers within view on page load\n\n#### Without bounds\n\n```python\n\n@app.route(\'/map-unbounded/\')\ndef map_unbounded():\n"""Create map with markers out of bounds."""\n    locations = []    # long list of coordinates\n    map = Map(\n        lat=locations[0].latitude,\n        lng=locations[0].longitude,\n        markers=[(loc.latitude, loc.longitude) for loc in locations]\n    )\n    return render_template(\'map.html\', map=map)\n\n```\n\n![image](https://user-images.githubusercontent.com/14223309/29294427-24a8d4e0-8104-11e7-967b-0c55c20d0f7c.png)\n\n#### With bounds\n\n```python\n\n@app.route(\'/map-bounded/\')\ndef map_bounded():\n"""Create map with all markers within bounds."""\n    locations = []    # long list of coordinates\n    map = Map(\n        lat=locations[0].latitude,\n        lng=locations[0].longitude,\n        markers=[(loc.latitude, loc.longitude) for loc in locations],\n        fit_markers_to_bounds = True\n    )\n    return render_template(\'map.html\', map=map)\n\n```\n\n![image](https://user-images.githubusercontent.com/14223309/29294483-6ac3e532-8104-11e7-988c-5c19d700fe5b.png)\n\n### Run the example app\n\n```bash\n$ git clone https://github.com/flask-extensions/Flask-GoogleMaps\n$ cd Flask-GoogleMaps/\n```\n\nIf you have Poetry\n\n```bash\n$ poetry install\n```\n\nwithout poetry\n\n```bash\n$ pip install --upgrade pip\n$ pip install -e .\n$ pip install -r requirements.txt\n```\n\nRun it.\n\n```bash\n$ FLASK_GOOGLEMAPS_KEY="YourKeyHERE" FLASK_APP=examples/example.py flask run\nrunning on localhost:5000 .....\n```\n\nAccess: http://localhost:5000/ and http://localhost:5000/fullmap\n\n## Contribute\n\nPlease see this page [developers.google.com/maps/documentation/javascript/tutorial](https://developers.google.com/maps/documentation/javascript/tutorial) and contribute!\n',
    'author': 'Riverfount - Vulgo Vicente Marçal',
    'author_email': 'vicente.marcal@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://flaskextensions.com',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6',
}


setup(**setup_kwargs)
